#!/usr/bin/env python

import ceilometerclient.v2 as c_client
import keystoneclient.v2_0.client as k_client
import os
import time

class MeterMaid(object):

    def __init__(self):
        self.keystone = self._init_keystone_client()
        self.ceilometer = self._init_ceilometer_client()

    def _init_keystone_client(self):
        # Read the information from the environment for who to talk to.
        OS_USERNAME = os.environ['OS_USERNAME']
        OS_PASSWORD = os.environ['OS_PASSWORD']
        OS_TENANT_NAME = os.environ['OS_TENANT_NAME']
        OS_AUTH_URL = os.environ['OS_AUTH_URL']
    
        return k_client.Client(auth_url=OS_AUTH_URL, username=OS_USERNAME,
                               password=OS_PASSWORD, tenant_name=OS_TENANT_NAME)

    def _init_ceilometer_client(self):
        ceil_svcs = [s for s in self.keystone.services.list() \
                     if s._info['type'] == 'metering']
    
        if len(ceil_svcs) == 0:
            raise Exception("Expected at least one ceilometer service.")
    
        ceil_endpts = [e for e in self.keystone.endpoints.list() \
                       if e._info['service_id'] == ceil_svcs[0]._info['id']]
    
        if len(ceil_endpts) == 0:
            raise Exception("Unable to find any ceilometer endpoints.")
    
        ceilometer_endpoint = ceil_endpts[0]._info['publicurl']
        auth_token = self.keystone.auth_token
        return c_client.Client(endpoint=ceilometer_endpoint,
                               token= lambda : auth_token)

    def create_samples(self, count=1, resource='test.resource',
                       meter='test.meter', type='gauge', unit='cnt',
                       value=None, delay=0, verbose=False):

        for i in xrange(count):
            sample_volume = value or i
            if verbose:
                print ("Creating sample of %d on resource %s with meter "
                       "%s." % (sample_volume, resource, meter))
            self.ceilometer.samples.create(counter_name=meter,
                                           counter_type=type,
                                           counter_unit=unit,
                                           counter_volume=sample_volume,
                                           resource_id=resource)
            if verbose:
                print ("Successfully created sample %d on resource "
                       "%s with meter %s." % (sample_volume, resource, meter))

            if delay > 0:
                time.sleep(delay)
                            
        return self.ceilometer.samples.list(meter_name=meter)


if __name__ == "__main__":
    mm = MeterMaid()
    print mm.create_samples(count=10, delay=1)
